F.automated.CDA(dist, group.size = 1, area = 1, total.trans.len = 1, w.lo = 0, w.hi = max(dist),
likelihoods = c("halfnorm", "hazrate", "uniform", "negexp", "Gamma"),
series = c("cosine", "hermite", "simple"), expansions = 0:3, plot = TRUE, ...)dist must be
between w.lo and w.hi.dist. This vector is replicated
as necessary to be the same length as dist. Default value
is 1, which assumes all sightings were individuals.F.abundist. This is the minimum
possible off-transect distance. Default is 0.dist. This is the maximum
off-transect distance that could be observed. Default is the maximum observed
distance.F.dfunc.estim, which in turn are passed to F.gx.estim.
These include x.scl, g.x.scl, and observer for estimating double observer probabilities.F.abund.estim and F.dfunc.estim).
Returned abundance estimates are based on the best fitting distance function amoung those
fitted.likelihoods has 3 elements,
series has 2 elements, and expansions has 4 elements, the total number of models fitted is
3 (likelihoods) X 2 (series) X 4 (expansions) = 24 models. By default, every available (classic) distance
function is fitted. The default specification results in 5 (likelihoods) X 3 (series) X 4 (expansions) = 60
fitted models. The model with lowest AIC is choosen as 'best', and estimation of abundance proceeds
using that model.F.dfunc.estim, F.abund.estimset.seed(234252)
x <- rnorm(1000) * 100
x <- x[ 0 < x & x < 100 ]
# Assume surveyed 10000 m in study area of size 1000 hectares.
N <- F.automated.CDA( x, area=1000*10000, total.trans.len=1000, w.hi = 100,
likelihood=c("halfnorm", "uniform", "Gamma"), series=c("cosine", "simple"),
expansions=c(0,1,2))Run the code above in your browser using DataLab