Learn R Programming

Rdistance (version 1.1)

coef.dfunc: Coefficients of an estimated distance function

Description

Extract the coefficients and estimated parameters (if any) from a estimated distance function object.

Usage

## S3 method for class 'dfunc':
coef(object, \dots)

Arguments

object
An estimated distance function object. An estimated distance function object has class 'dfunc', and is usually produced by a call to F.dfunc.estim.
...
Required for compatability with the general coef method. Any extra arguments to this function are ignored.

Value

  • The estimated parameter vector for the distance function. Length and interpretation of values in this vector vary depending on the form of the distance function and expansion terms.

Details

This is an extractor function for the parameters of an estimated distance function. This function is equivalent to obj$parameters for classical distance functions.

See Also

AIC, F.dfunc.estim

Examples

Run this code
set.seed(5553)
x <- rnorm(1000) * 100
x <- x[ 0 < x & x < 100 ]
fit <- F.dfunc.estim(x, w.lo=0, w.hi=100)
coef(fit)  
fit <- F.dfunc.estim(x, w.lo=0, w.hi=100, expansions=1)
coef(fit)

Run the code above in your browser using DataLab