expandW: Domain of expansion factors

View source: R/expandW.R

expandWR Documentation

Domain of expansion factors

Description

The domain to which expansion factors are applied varies by likelihood. When the domain varies, it depends on parameter values. For example, oneStep expansion factors are applied between 0 and the likelihood's first parameter (\theta), which varies by covariates. This function computes the likelihood-specific expansion domains

Usage

expandW(ml, params, k)

Arguments

ml

Either a Rdistance 'model frame' or an Rdistance 'fitted object'. Both are of class "dfunc". Rdistance 'model frames' are lists containing components necessary to estimate a distance function, but no estimates. Rdistance 'model frames' are typically produced by calls to parseModel. Rdistance 'fitted objects' are typically produced by calls to dfuncEstim. 'Fitted objects' are 'model frames' with additional components such as the parameters estimates, log likelihood value, convergence information, and the variance- covariance matrix of the parameters.

params

A matrix of likelihood parameters. Size is (number of distances) X [(number of cases) + (number of non-covariate parameter)].

k

The number of cases.

Value

A plain vector of length k containing expansion domains, with units.


Rdistance documentation built on April 23, 2026, 1:06 a.m.