View source: R/halfnorm.like.R
| halfnorm.like | R Documentation |
Evaluate the half-normal distance function, for sighting distances, potentially including covariates and expansion terms
halfnorm.like(a, dist, covars, w.hi = NULL)
a |
A vector or matrix of covariate
and expansion term
coefficients. If matrix, dimension is
k X p, where
k = |
dist |
A numeric vector of length n or a single-column matrix (dimension nX1) containing detection distances at which to evaluate the likelihood. |
covars |
A numeric vector of length q or a
matrix of dimension nXq containing
covariate values
associated with distances in argument |
w.hi |
A numeric scalar containing maximum distance. The right-hand cutoff or upper limit. Ignored by some likelihoods (such as halfnorm, negexp, and hazrate), but is a fixed parameter in other likelihoods (such as oneStep and uniform). |
The half-normal distance function is
f(d|\sigma) = \exp(-\frac{d^2}{2\sigma^2})
where \sigma = exp(x'a), x is a vector of
covariate values associated with distance d
(i.e., a row of covars), and
a is a vector of the first $q$ (=ncol(covars))
values in argument a.
Some authors parameterize the halfnorm without
the "2" in the denominator of the exponent.
Rdistance includes
"2" in this denominator to make
quantiles of the half normal agree with
the standard normal. This means that half-normal
coefficients in
Rdistance (i.e., \sigma = exp(x'a)) can be
interpreted as normal standard errors.
Approximately 95% of distances should
occur between 0 and 2\sigma.
A list containing the following two components:
L.unscaled: A matrix of size
nXk (n = length dist; k = number of
cases = nrow(a))
containing likelihood values evaluated at
distances in dist.
Each row is associated with
a single distance, and each column is associated with
a single case (row of a). Values in this matrix are
the distance function g(d) which generally have g(0) = 1.
These values are "unscaled" likelihood values; they must be
scaled (divided by) with the area under g(x) between w.lo and w.hi
to form proper likelihood values.
params: A nXbXk array
of the likelihood's (canonical) parameters in link space (i.e., on
log scale; b = number of canonical parameters in
the likelihood; k = number of cases).
Rows correspond to distances in dist. Columns
correspond to parameters (columns of a),
and pages correspond to cases (rows of a).
dfuncEstim,
abundEstim,
other <likelihood>.like functions
d <- seq(0, 100, length=100)
covs <- matrix(1,length(d),1)
halfnorm.like(log(20), d, covs)
plot(d, halfnorm.like(log(20), d, covs)$L.unscaled, type="l", col="red")
lines(d, halfnorm.like(log(40), d, covs)$L.unscaled, col="blue")
# Evaluate 3 functions at once using matrix of coefficients:
# sigma ~ 20, 30, 40
coefs <- matrix(log(c(7.39,7.33, 4.48,44.80, 2.72,216.54))
, byrow = TRUE
, ncol=2) # (3 coef vectors)X(2 covars)
covs <- matrix(c(rep(1,length(d))
, rep(0.5,length(d)))
, nrow = length(d)) # 100 X 2
L <- halfnorm.like( coefs, d, covs )
L$L.unscaled # 100 X (3 coef vectors)
L$params # 100 X (3 coef vectors); ~ log(c(20,30,40))
matplot(d, L$L.unscaled, type="l")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.