View source: R/integrateOneStepNumeric.R
| integrateOneStepNumeric | R Documentation |
Compute integral of the one-step distance function using numeric integration. This function is only called for oneStep functions that contain expansion factors.
integrateOneStepNumeric(
object,
newdata = NULL,
w.lo = NULL,
w.hi = NULL,
Units = NULL,
expansions = NULL,
series = NULL,
isPoints = NULL
)
object |
Either an Rdistance fitted distance function
(an object that inherits from class "dfunc"; usually produced
by a call to |
newdata |
A data frame containing new values for
the distance function covariates. If NULL and
|
w.lo |
Minimum sighting distance or left-truncation value
if |
w.hi |
Maximum sighting distance or right-truncation value
if |
Units |
Physical units of sighting distances if
|
expansions |
A scalar specifying the number of terms
in |
series |
If |
isPoints |
Boolean. TRUE if integration is for point surveys. FALSE for line-transect surveys. Line-transect surveys integrate under the distance function, g(x), while point surveys integrate under the distance function times distances, xg(x). |
The oneStep.like() function has an extremely large
discontinuity at Theta. Accurate numeric integration requires
inserting Theta and Theta+ (a value just larger than Theta)
into the series of points being evaluated. Because this creates
variable sized intervals, the Trapezoid rule must be used.
Rdistance's Simpson's rule routine
(integrateNumeric()) will not work for oneStep likelihoods
that have expansions.
A vector of areas under the distance functions represented in
object.
If object is a distance function and
newdata is specified, the returned vector's length is
nrow(newdata). If object is a distance function and
newdata is NULL,
returned vector's length is length(distances(object)). If
object is a matrix, return's length is
nrow(object).
Users will not normally call this function. It is called
internally by nLL() and effectiveDistance().
integrateNumeric();
integrateOneStepLines(); integrateOneStepPoints()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.