is.Unitless: Test whether object is unitless

View source: R/is.Unitless.R

is.UnitlessR Documentation

Test whether object is unitless

Description

Tests whether a 'units' object is actually unitless. Unitless objects, such as ratios, should be assigned units of [1]. Often they are, but sometimes unitless ratios are assigned units like [m/m]. The units package should always convert [m/m] to [1], but it does not always. Sometimes units like [m/m] mess things up, so it is better to remove them before calculations.

Usage

is.Unitless(obj)

Arguments

obj

A numeric scalar or vector, with or without units.

Value

TRUE if obj has units and they are either [1] or the denominator units equal the numerator units. Otherwise, return FALSE. If obj does not have units, this routine returns TRUE.

Examples

a <- setUnits(2, "m")
b <- a / a
is.Unitless(a)
is.Unitless(b)
is.Unitless(3)


Rdistance documentation built on May 14, 2026, 5:09 p.m.