likeParamNames: Likelihood parameter names

View source: R/likeParamNames.r

likeParamNamesR Documentation

Likelihood parameter names

Description

Returns names of the likelihood parameters. This is a helper function and is not necessary for estimation. It is nice to label some parameters with descriptive names like "sigma" or "k", depending on the likelihood.

Usage

likeParamNames(like.form)

Arguments

like.form

A text string naming the form of the likelihood. An error is thrown if the likelihood is unknown.

Value

A vector of parameter names for the likelihood


Rdistance documentation built on April 23, 2026, 1:06 a.m.