coef.dfunc: Coefficients of an estimated distance function
Description
Extract the coefficients and estimated parameters (if any) from
a estimated distance function object.
Usage
## S3 method for class 'dfunc':
coef(object, \dots)
Arguments
object
An estimated distance function object. An estimated distance
function object has class 'dfunc', and is usually produced by a call to
F.dfunc.estim.
...
Required for compatability with the general coef method. Any
extra arguments to this function are ignored.
Value
The estimated parameter vector for the distance function. Length and interpretation of values
in this vector vary depending on the form of the distance function and expansion terms.
Details
This is an extractor function for the parameters of an estimated distance function.
This function is equivalent to obj$parameters for classical distance functions.