| expandW | R Documentation |
The domain to which expansion factors are applied varies by likelihood.
When the domain varies, it depends on parameter values. For example,
oneStep expansion factors are applied between
0 and the likelihood's first parameter (\theta), which
varies by covariates. This function computes the likelihood-specific
expansion domains
expandW(ml, params, k)
ml |
Either a Rdistance 'model frame' or an Rdistance
'fitted object'. Both are of class "dfunc".
Rdistance 'model frames' are lists containing components
necessary to estimate a distance function, but no estimates.
Rdistance 'model frames' are typically
produced by calls to |
params |
A matrix of likelihood parameters. Size is (number of distances) X [(number of cases) + (number of non-covariate parameter)]. |
k |
The number of cases. |
A plain vector of length k containing expansion domains, with units.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.