View source: R/likeParamNames.r
| likeParamNames | R Documentation |
Returns names of the likelihood parameters. This is a helper function and is not necessary for estimation. It is nice to label some parameters with descriptive names like "sigma" or "k", depending on the likelihood.
likeParamNames(like.form)
like.form |
A text string naming the form of the likelihood. An error is thrown if the likelihood is unknown. |
A vector of parameter names for the likelihood
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.