| setOptimizer | R Documentation |
Checks that the maximum likelihood optimizing routine is appropriate for the requested likelihood function. That is, checks that gradient based maximization routines are only applied to smooth likelihoods, and that gradient-free methods are used for non-smooth likelihoods.
setOptimizer(ml)
ml |
Either a Rdistance 'model frame' or an Rdistance
'fitted object'. Both are of class "dfunc".
Rdistance 'model frames' are lists containing components
necessary to estimate a distance function, but no estimates.
Rdistance 'model frames' are typically
produced by calls to |
If Rdistance options are changed, a list of the options and their original values. The return can be used outside this routine to set options back to their state when this routine was entered. If no options changed, the return in NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.